Database
--------

Problematic
^^^^^^^^^^^

How can we store our most relevant information?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.database
   :members:
   :private-members:


:code:`InactiveDB()`
""""""""""""""""""""

.. autoclass:: PyFunceble.database.inactive.InactiveDB
    :members:
    :private-members:

:code:`WhoisDB()`
"""""""""""""""""

.. autoclass:: PyFunceble.database.whois.WhoisDB
    :members:
    :private-members: